#!/bin/bash
# automanren.sh -- automatic manual rename
# Peter Fokker -- 2011-02-04

MV="/bin/mv"
RENAME="/usr/bin/rename"
SED="/bin/sed"
CUT="/bin/cut"
LS="/bin/ls"

PROG="$(/bin/basename "$0")"

for cmd in "$MV" "$RENAME" "$SED" "$CUT" "$LS"; do
  if [ -x "$cmd" ]; then
    echo "$PROG: found $cmd, good"
  else
    echo "$PROG: cannot find $cmd; bailing out..."
    exit 1
  fi
done
echo ""

FROMTO="modman:modulemanager guidtour:guidedtour"
for ft in $FROMTO; do
  OLD="$(echo "$ft" | $CUT -f 1 -d ':')"
  NEW="$(echo "$ft" | $CUT -f 2 -d ':')"
  echo "$PROG: renaming from $OLD to $NEW"
  if [ ! -d "$OLD" ]; then
    echo "$PROG: cannot find directory $OLD; are we here for a second time? Hmmm, skipping this one..."
  elif [ -d "$NEW" ]; then
    echo "$PROG: new directory $NEW already exists, skipping this one..."
  else
    echo "$PROG: descending into $OLD"
    cd "$OLD"

    echo "$PROG: renaming files from $OLD to $NEW"
    "$RENAME" "$OLD" "$NEW" *
    # echo "$PROG: new names:"
    # "$LS" -l

    echo "$PROG: leaving $OLD"
    cd ..

    echo "$PROG: renaming directory $OLD to $NEW"
    "$MV" "$OLD/" "$NEW/"
    "$LS" -ld "$NEW/"

  fi

  echo "$PROG: stream-editing HTML-files in situ, changing all references"
  "$SED" -i -e "s/${OLD}\/${OLD}/${NEW}\/${NEW}/g" \
            -e "s/${OLD}\//${NEW}\//g"             \
            -e "s/${OLD}_/${NEW}_/g"               \
            -e "s/${OLD}.html/${NEW}.html/g"       \
            *.html

  if [ ! -f "${OLD}.html" ]; then
    echo "$PROG: file ${OLD}.html not found; cannot rename"
  elif [ -f "${NEW}.html" ]; then
    echo "$PROG: file ${NEW}.html already exists; cannot rename"
  else
    echo "$PROG: finally renaming the HTML-file itself"
    "$MV" "${OLD}.html" "${NEW}.html"
  fi
  echo ""
done
echo "$PROG: done"
